# hoopR-py <a href='https://hoopR-py.sportsdataverse.org/'><img src='https://hoopR-py.sportsdataverse.org/img/hoopR-py-logo.png' align="right" height="150" /></a>
<!-- badges: start -->

![Lifecycle:experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg?style=for-the-badge&logo=github)
[![PyPI](https://img.shields.io/pypi/v/hoopR-py?label=hoopr-py&logo=python&style=for-the-badge)](https://pypi.org/project/hoopR-py/)
![Contributors](https://img.shields.io/github/contributors/saiemgilani/hoopR-py?style=for-the-badge)
[![Twitter
Follow](https://img.shields.io/twitter/follow/saiemgilani?color=blue&label=%40saiemgilani&logo=twitter&style=for-the-badge)](https://twitter.com/saiemgilani)

<!-- badges: end -->


See [CHANGELOG.md](http://hoopr-py.sportsdataverse.org/CHANGELOG) for details.

[hoopR-py](https://hoopr-py.sportsdataverse.org/) is an Python package for working with men’s basketball data and companion package to [hoopR](https://saiemgilani.github.io/hoopR/)

The package has functions to access live play by play and box score data from ESPN with shot locations when available.

## Installation

hoopR-py can be installed via pip:

```bash
pip install hoopR-py
```

or from the repo (which may at times be more up to date):

```bash
git clone https://github.com/saiemgilani/hoopR-py
cd hoopR-py
pip install -e .
```


# **Our Authors**

-   [Saiem Gilani](https://twitter.com/saiemgilani)       
<a href="https://twitter.com/saiemgilani" target="blank"><img src="https://img.shields.io/twitter/follow/saiemgilani?color=blue&label=%40saiemgilani&logo=twitter&style=for-the-badge" alt="@saiemgilani" /></a>
<a href="https://github.com/saiemgilani" target="blank"><img src="https://img.shields.io/github/followers/saiemgilani?color=eee&logo=Github&style=for-the-badge" alt="@saiemgilani" /></a>


## **Citations**

To cite the [**`hoopR-py`**](https://hoopr-py.sportsdataverse.org/) Python package in publications, use:

BibTex Citation
```bibtex
@misc{saiemgilani2021hoopRpy,
  author = {Gilani, Saiem},
  title = {hoopR-py: The SportsDataverse's Python Package for Men's Basketball Data.},
  url = {https://hoopR-py.sportsdataverse.org/},
  year = {2021}
}
```
